@@ -8,18 +8,18 @@
 // <int>.<int>.<int>-<any text>.
 // or else upgrading old project file will not work
 // reliably.
-#define VERSION "3.2.3-Bonn"
+#define VERSION "3.6.0-Noosa"
 
 //used in vim src/core/qgis.cpp
 //The way below should work but it resolves to a number like 0110 which the compiler treats as octal I think
 //because debuggin it out shows the decimal number 72 which results in incorrect version status.
 //As a short term fix I (Tim) am defining the version in top level cmake. It would be good to
 //reinstate this more generic approach below at some point though
-//#define VERSION_INT 323
-#define VERSION_INT 30203
-#define ABISYM(x) x ## 30203
+//#define VERSION_INT 360
+#define VERSION_INT 30600
+#define ABISYM(x) x ## 30600
 //used in main.cpp and anywhere else where the release name is needed
-#define RELEASE_NAME "Bonn"
+#define RELEASE_NAME "Noosa"
 
 #define QGIS_PLUGIN_SUBDIR "lib/qgis/plugins"
 #define QGIS_DATA_SUBDIR "share/qgis"
@@ -27,7 +27,7 @@
 #define QGIS_LIB_SUBDIR "lib"
 #define QGIS_QML_SUBDIR "qml"
 #define CMAKE_INSTALL_PREFIX "/usr/local"
-#define CMAKE_SOURCE_DIR "/usr/obj/ports/qgis-3.2.3/qgis-3.2.3"
+#define CMAKE_SOURCE_DIR "/usr/obj/ports/qgis-3.6.0/qgis-3.6.0"
 
 #define QGIS_SERVER_MODULE_SUBDIR "lib/qgis/server"
 
@@ -57,6 +57,8 @@
 
 #define HAVE_SERVER_PYTHON_PLUGINS
 
+/* #undef HAVE_OPENCL */
+
 /* #undef ENABLE_MODELTEST */
 
 #define HAVE_3D
@@ -67,5 +69,7 @@
 
 /* #undef HAVE_QUICK */
 
+#define HAVE_QT5SERIALPORT
+
 #endif
 
