@@ -16,18 +16,17 @@
 *                                                                         *
 ***************************************************************************
 """
+from builtins import str
 
 __author__ = 'Giuseppe Sucameli'
 __date__ = 'April 2012'
 __copyright__ = '(C) 2012, Giuseppe Sucameli'
 # This will get replaced with a git SHA1 when you do a git archive
-__revision__ = '$Format:%H$'
+__revision__ = '58734527abdbaab95719a48a4a64ea05abd70b44'
 
-from PyQt4.QtCore import SIGNAL
-from PyQt4.QtGui import QDialog, QMessageBox
+from qgis.PyQt.QtWidgets import QDialog, QMessageBox
 
 from .db_plugins.plugin import TableField
-
 from .ui.ui_DlgFieldProperties import Ui_DbManagerDlgFieldProperties as Ui_Dialog
 
 
@@ -42,9 +41,15 @@ class DlgFieldProperties(QDialog, Ui_Dialog):
 
         for item in self.db.connector.fieldTypes():
             self.cboType.addItem(item)
-        self.setField(self.fld)
 
-        self.connect(self.buttonBox, SIGNAL("accepted()"), self.onOK)
+        supportCom = self.db.supportsComment()
+        if not supportCom:
+            self.label_6.setVisible(False)
+            self.editCom.setVisible(False)
+
+        self.setField(fld)
+
+        self.buttonBox.accepted.connect(self.onOK)
 
     def setField(self, fld):
         if fld is None:
@@ -52,10 +57,14 @@ class DlgFieldProperties(QDialog, Ui_Dialog):
         self.editName.setText(fld.name)
         self.cboType.setEditText(fld.dataType)
         if fld.modifier:
-            self.editLength.setText(unicode(fld.modifier))
+            self.editLength.setText(str(fld.modifier))
         self.chkNull.setChecked(not fld.notNull)
         if fld.hasDefault:
             self.editDefault.setText(fld.default)
+        tab = self.table.name
+        field = fld.name
+        res = self.db.connector.getComment(tab, field)
+        self.editCom.setText(res) # Set comment value
 
     def getField(self, newCopy=False):
         fld = TableField(self.table) if not self.fld or newCopy else self.fld
@@ -64,6 +73,8 @@ class DlgFieldProperties(QDialog, Ui_Dialog):
         fld.notNull = not self.chkNull.isChecked()
         fld.default = self.editDefault.text()
         fld.hasDefault = fld.default != ""
+        # Get the comment from the LineEdit
+        fld.comment = self.editCom.text()
         try:
             modifier = int(self.editLength.text())
         except ValueError:
@@ -77,10 +88,10 @@ class DlgFieldProperties(QDialog, Ui_Dialog):
         """ first check whether everything's fine """
         fld = self.getField(True)  # don't change the original copy
         if fld.name == "":
-            QMessageBox.critical(self, self.tr("DB Manager"), self.tr("field name must not be empty"))
+            QMessageBox.critical(self, self.tr("DB Manager"), self.tr("Field name must not be empty."))
             return
         if fld.dataType == "":
-            QMessageBox.critical(self, self.tr("DB Manager"), self.tr("field type must not be empty"))
+            QMessageBox.critical(self, self.tr("DB Manager"), self.tr("Field type must not be empty."))
             return
 
         self.accept()
