@@ -23,15 +23,14 @@ __copyright__ = '(C) 2013, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '$Format:%H$'
+__revision__ = '58734527abdbaab95719a48a4a64ea05abd70b44'
 
-from PyQt4.QtCore import QSettings
-from qgis.core import QgsVectorFileWriter
+from qgis.core import QgsVectorFileWriter, QgsSettings, QgsProcessingUtils
 
 from processing.core.GeoAlgorithm import GeoAlgorithm
 from processing.core.parameters import ParameterVector
 from processing.core.outputs import OutputVector
-from processing.tools import dataobjects, vector
+from processing.tools import dataobjects
 
 
 class ExampleAlgorithm(GeoAlgorithm):
@@ -55,28 +54,37 @@ class ExampleAlgorithm(GeoAlgorithm):
     OUTPUT_LAYER = 'OUTPUT_LAYER'
     INPUT_LAYER = 'INPUT_LAYER'
 
-    def defineCharacteristics(self):
+    def __init__(self):
+        super().__init__()
         """Here we define the inputs and output of the algorithm, along
         with some other properties.
         """
 
-        # The name that the user will see in the toolbox
-        self.name, self.i18n_name = self.trAlgorithm('Create copy of layer')
-
-        # The branch of the toolbox under which the algorithm will appear
-        self.group, self.i18n_group = self.trAlgorithm('Algorithms for vector layers')
-
         # We add the input vector layer. It can have any kind of geometry
         # It is a mandatory (not optional) one, hence the False argument
         self.addParameter(ParameterVector(self.INPUT_LAYER,
-                                          self.tr('Input layer'), [ParameterVector.VECTOR_TYPE_ANY], False))
+                                          self.tr('Input layer'), [dataobjects.TYPE_VECTOR_ANY], False))
 
         # We add a vector layer as output
         self.addOutput(OutputVector(self.OUTPUT_LAYER,
                                     self.tr('Output layer with selected features')))
 
-    def processAlgorithm(self, progress):
-        """Here is where the processing itself takes place."""
+    def name(self):
+        # Unique (non-user visible) name of algorithm
+        return 'create_copy_of_layer'
+
+    def displayName(self):
+        # The name that the user will see in the toolbox
+        return self.tr('Create copy of layer')
+
+    def group(self):
+        return self.tr('Algorithms for vector layers')
+
+    def processAlgorithm(self, parameters, context, feedback):
+        """Here is where the processing itself takes place.
+        :param parameters:
+        :param context:
+        """
 
         # The first thing to do is retrieve the values of the parameters
         # entered by the user
@@ -84,29 +92,30 @@ class ExampleAlgorithm(GeoAlgorithm):
         output = self.getOutputValue(self.OUTPUT_LAYER)
 
         # Input layers vales are always a string with its location.
-        # That string can be converted into a QGIS object (a
+        # That string can be converted into a QGIS layer (a
         # QgsVectorLayer in this case) using the
-        # processing.getObjectFromUri() method.
-        vectorLayer = dataobjects.getObjectFromUri(inputFilename)
+        # QgsProcessingUtils.mapLayerFromString() method.
+        vectorLayer = QgsProcessingUtils.mapLayerFromString(inputFilename, context)
 
         # And now we can process
 
         # First we create the output layer. The output value entered by
         # the user is a string containing a filename, so we can use it
         # directly
-        settings = QSettings()
+        settings = QgsSettings()
         systemEncoding = settings.value('/UI/encoding', 'System')
-        provider = vectorLayer.dataProvider()
-        writer = QgsVectorFileWriter(output, systemEncoding,
-                                     provider.fields(),
-                                     provider.geometryType(), provider.crs())
+        writer = QgsVectorFileWriter(output,
+                                     systemEncoding,
+                                     vectorLayer.fields(),
+                                     vectorLayer.wkbType(),
+                                     vectorLayer.crs())
 
         # Now we take the features from input layer and add them to the
         # output. Method features() returns an iterator, considering the
         # selection that might exist in layer and the configuration that
         # indicates should algorithm use only selected features or all
         # of them
-        features = vector.features(vectorLayer)
+        features = QgsProcessingUtils.getFeatures(vectorLayer, context)
         for f in features:
             writer.addFeature(f)
 
