@@ -23,14 +23,14 @@ __copyright__ = '(C) 2016, Médéric Ribreux'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '$Format:%H$'
+__revision__ = '58734527abdbaab95719a48a4a64ea05abd70b44'
 
-from r_li import checkMovingWindow, configFile
+from .r_li import checkMovingWindow, configFile
 
 
-def checkParameterValuesBeforeExecuting(alg):
-    return checkMovingWindow(alg)
+def checkParameterValuesBeforeExecuting(alg, parameters, context):
+    return checkMovingWindow(alg, parameters, context)
 
 
-def processCommand(alg):
-    configFile(alg)
+def processCommand(alg, parameters, context, feedback):
+    configFile(alg, parameters, context, feedback)
