@@ -23,7 +23,7 @@ __copyright__ = '(C) 2013, Alexander Bruy'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '9b176802e5512bc310765d8ebe4e44b5f4663453'
+__revision__ = '58734527abdbaab95719a48a4a64ea05abd70b44'
 
 import math
 from qgis.core import (QgsFeatureSink,
@@ -116,7 +116,7 @@ class PointsDisplacement(QgisAlgorithm):
 
             other_features_within_radius = index.intersects(searchRect(point))
             if not other_features_within_radius:
-                index.insertFeature(f)
+                index.addFeature(f)
                 group = [f]
                 clustered_groups.append(group)
                 group_index[f.id()] = len(clustered_groups) - 1
