@@ -23,20 +23,27 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '$Format:%H$'
+__revision__ = '58734527abdbaab95719a48a4a64ea05abd70b44'
 
 import os
 import json
+import warnings
 
 from qgis.PyQt import uic
 from qgis.PyQt.QtWidgets import QDialog, QTreeWidgetItem
 
-from processing.core.ProcessingLog import ProcessingLog
-from processing.modeler.ModelerAlgorithm import ModelerAlgorithm
+from qgis.core import (Qgis,
+                       QgsMessageLog,
+                       QgsProcessingUtils,
+                       QgsProcessingParameterDefinition,
+                       QgsProcessingModelAlgorithm)
 
 pluginPath = os.path.split(os.path.dirname(__file__))[0]
-WIDGET, BASE = uic.loadUiType(
-    os.path.join(pluginPath, 'ui', 'DlgHelpEdition.ui'))
+
+with warnings.catch_warnings():
+    warnings.filterwarnings("ignore", category=DeprecationWarning)
+    WIDGET, BASE = uic.loadUiType(
+        os.path.join(pluginPath, 'ui', 'DlgHelpEdition.ui'))
 
 
 class HelpEditionDialog(BASE, WIDGET):
@@ -45,6 +52,8 @@ class HelpEditionDialog(BASE, WIDGET):
     ALG_CREATOR = 'ALG_CREATOR'
     ALG_HELP_CREATOR = 'ALG_HELP_CREATOR'
     ALG_VERSION = 'ALG_VERSION'
+    SHORT_DESCRIPTION = 'SHORT_DESCRIPTION'
+    HELP_URL = 'HELP_URL'
 
     def __init__(self, alg):
         super(HelpEditionDialog, self).__init__(None)
@@ -52,8 +61,8 @@ class HelpEditionDialog(BASE, WIDGET):
 
         self.alg = alg
         self.descriptions = {}
-        if isinstance(self.alg, ModelerAlgorithm):
-            self.descriptions = self.alg.helpContent
+        if isinstance(self.alg, QgsProcessingModelAlgorithm):
+            self.descriptions = self.alg.helpContent()
         else:
             if self.alg.descriptionFile is not None:
                 helpfile = alg.descriptionFile + '.help'
@@ -62,8 +71,7 @@ class HelpEditionDialog(BASE, WIDGET):
                         with open(helpfile) as f:
                             self.descriptions = json.load(f)
                     except Exception:
-                        ProcessingLog.addToLog(ProcessingLog.LOG_WARNING,
-                                               self.tr('Cannot open help file: %s') % helpfile)
+                        QgsMessageLog.logMessage(self.tr('Cannot open help file: {0}').format(helpfile), self.tr('Processing'), Qgis.Warning)
 
         self.currentName = self.ALG_DESC
         if self.ALG_DESC in self.descriptions:
@@ -78,34 +86,39 @@ class HelpEditionDialog(BASE, WIDGET):
         QDialog.reject(self)
 
     def accept(self):
-        self.descriptions[self.currentName] = unicode(self.text.toPlainText())
+        self.descriptions[self.currentName] = str(self.text.toPlainText())
         QDialog.accept(self)
 
     def getHtml(self):
         s = self.tr('<h2>Algorithm description</h2>\n')
         s += '<p>' + self.getDescription(self.ALG_DESC) + '</p>\n'
         s += self.tr('<h2>Input parameters</h2>\n')
-        for param in self.alg.parameters:
-            s += '<h3>' + param.description + '</h3>\n'
-            s += '<p>' + self.getDescription(param.name) + '</p>\n'
+        for param in self.alg.parameterDefinitions():
+            s += '<h3>' + param.description() + '</h3>\n'
+            s += '<p>' + self.getDescription(param.name()) + '</p>\n'
         s += self.tr('<h2>Outputs</h2>\n')
-        for out in self.alg.outputs:
-            s += '<h3>' + out.description + '</h3>\n'
-            s += '<p>' + self.getDescription(out.name) + '</p>\n'
+        for out in self.alg.outputDefinitions():
+            s += '<h3>' + out.description() + '</h3>\n'
+            s += '<p>' + self.getDescription(out.name()) + '</p>\n'
         return s
 
     def fillTree(self):
         item = TreeDescriptionItem(self.tr('Algorithm description'), self.ALG_DESC)
         self.tree.addTopLevelItem(item)
+        item = TreeDescriptionItem(self.tr('Short description'), self.SHORT_DESCRIPTION)
+        self.tree.addTopLevelItem(item)
         parametersItem = TreeDescriptionItem(self.tr('Input parameters'), None)
         self.tree.addTopLevelItem(parametersItem)
-        for param in self.alg.parameters:
-            item = TreeDescriptionItem(param.description, param.name)
+        for param in self.alg.parameterDefinitions():
+            if param.flags() & QgsProcessingParameterDefinition.FlagHidden or param.isDestination():
+                continue
+
+            item = TreeDescriptionItem(param.description(), param.name())
             parametersItem.addChild(item)
         outputsItem = TreeDescriptionItem(self.tr('Outputs'), None)
         self.tree.addTopLevelItem(outputsItem)
-        for out in self.alg.outputs:
-            item = TreeDescriptionItem(out.description, out.name)
+        for out in self.alg.outputDefinitions():
+            item = TreeDescriptionItem(out.description(), out.name())
             outputsItem.addChild(item)
         item = TreeDescriptionItem(self.tr('Algorithm created by'), self.ALG_CREATOR)
         self.tree.addTopLevelItem(item)
@@ -115,12 +128,15 @@ class HelpEditionDialog(BASE, WIDGET):
         item = TreeDescriptionItem(self.tr('Algorithm version'),
                                    self.ALG_VERSION)
         self.tree.addTopLevelItem(item)
+        item = TreeDescriptionItem(self.tr('Documentation help URL'),
+                                   self.HELP_URL)
+        self.tree.addTopLevelItem(item)
 
     def changeItem(self):
         item = self.tree.currentItem()
         if isinstance(item, TreeDescriptionItem):
             if self.currentName:
-                self.descriptions[self.currentName] = unicode(self.text.toPlainText())
+                self.descriptions[self.currentName] = str(self.text.toPlainText())
             name = item.name
             if name:
                 self.text.setEnabled(True)
